from peewee import *

db = MySQLDatabase(None)


class ConnectionMySql:
    
    def connection_db(database: str, user: str, password: str, host: str):
        '''It is necessary to fill in data for authorization in the database.'''
        
        db.init(database, user=user, password=password, host=host) 


from numpy import insert
from peewee import *
import sys
sys.path.insert(0, "TableCity")
from Connection_mysql_db.connection_mysql_db import *


class BaseClass(Model):
    
    class Meta():
        database = db
        primary_key = False
        


from peewee import *
import sys
sys.path.insert(0, "TableCity")
from Connection_mysql_db.connection_mysql_db import *
from BaseModel import *
from Country import *


class City(BaseClass):

    id = AutoField()
    city_name = CharField(50, null=False, unique=True)
    country_id = IntegerField(null=False)
    civils = IntegerField(null=False)
    area = FloatField()
    
    @staticmethod
    def cities_list():
        '''Print City table'''
        with db:
            order = City.select()
            for row in order:
                print(row.id, row.city_name, row.country_id, row.civils, row.area)
    
    def add_city(city_name: str, country_id: int, civils: int, area: float):
        '''Add other sities'''
        with db:
            data = [
                (city_name, country_id, civils, area)
            ]
            City.insert_many(data, fields=[City.city_name, City.civils, City.country_id, City.area]).execute()
    

    class Meta():
        table_name = 'Cities'


from enum import auto
from peewee import *
import sys
sys.path.insert(0, "TableCity")
from Connection_mysql_db.connection_mysql_db import *
from BaseModel import *


class Country(BaseClass):

    id = AutoField()
    country_name = CharField(50, null=False, unique=True)

    @staticmethod
    def countries_list():
        '''Print City table'''
        with db:
            order = Country.select()
            for row in order:
                print(row.id, row.country_name)
            
    def add_country(name: int):
        '''Add country'''
        with db:
            new_country = Country(country_name = name.lower().strip(),)
            new_country.save()
    
    class Meta():
        table_name = 'Countries'
        


from peewee import *
import sys
sys.path.insert(0, "TableCity")
from Connection_mysql_db.connection_mysql_db import *
from BaseModel import *
from Country import *
from City import *


class Density(BaseClass):

    city_id = IntegerField(null=False, index=True)
    density_value = FloatField(null=False)
    
    @staticmethod
    def density_list():
        order = Density.select()
        for row in order:
            print(row.city_id, row.density_value)
            
    def add_density(id: int):
        value = City.select((City.area / City.civils)).where(City.id == id)
        new_value = Density(density_value = value, city_id = id,)
        new_value.save()

    class Meta():
        table_name = 'Densities'


from peewee import *
import sys
sys.path.insert(0, "D:\Python\TableCity\TableCity")
from Connection_mysql_db.connection_mysql_db import *
from Tables import *


ConnectionMySql.connection_db('mydb', 'root', '12345678', 'localhost')

db.create_tables([City, Country, Density])

Country.add_country('Belarus')
Country.add_country('Poland')
Country.add_country('Ukrain')

City.add_city('Minsk', 1, 200000, 456.8)
City.add_city('Warsaw', 2, 2500000, 501.5)
City.add_city('Kiev', 3, 2350000, 486.1)

Density.add_density(1)
Density.add_density(2)
Density.add_density(3)


def db_to_print():
    with db:
        dict = (Country.select()
                .join(City, JOIN.LEFT_OUTER, on=(Country.id == City.country_id))
                .join(Density, JOIN.LEFT_OUTER, on=(City.id == Density.city_id))|
                Country.select()
                .join(City, JOIN.RIGHT_OUTER, on=(Country.id == City.country_id))
                .join(Density, JOIN.RIGHT_OUTER, on=(City.id == Density.city_id)))
        for item in dict.dicts().execute():
            print(item)
    

db_to_print()



    # def add_density_id(id: int):
    #     '''Add city id'''
    #     with db:
    #         new_id = Density(city_id = id,)
    #         new_id.save()